from django.apps import AppConfig


class Config(AppConfig):
    name = "unicef_locations"
    label = "unicef_locations"
